.. _quantum-boron:

quantum/boron.py
================

**Description**


Boron atom with 1 electron.

See :ref:`quantum-quantum_common`.


.. image:: /../doc/images/gallery/quantum-boron.png


:download:`source code </../sfepy/examples/quantum/boron.py>`

.. literalinclude:: /../sfepy/examples/quantum/boron.py

